@@ -7,6 +7,7 @@ def main():
     )
     parser.add_argument("inputfile", action="store", help="Input file")
     parser.add_argument("--fill", action="store", help="byte to fill [default: 0xff]")
+    parser.add_argument("-w", action="store", help="width")
     args = parser.parse_args()
 
     with open(args.inputfile, "rb") as in_file:
@@ -17,21 +18,21 @@ def main():
             data = in_file.read(1)
             data_array.append(data)
 
-        in_file.close()
-
         hex_array = [hex(int.from_bytes(byte, "big")) for byte in data_array]
-        length = len(hex_array)
+        if not args.w:
+            length = len(hex_array)
 
-        n = length
-        while n % n ** 0.5 != 0:
-            n += 1
-        sqrt_n = int(n ** 0.5)
+            n = length
+            while n % n ** 0.5 != 0:
+                n += 1
+            sqrt_n = int(n ** 0.5)
 
-        padding = n - length
-        for i in range(padding):
-            hex_array.append(args.fill if args.fill is not None else hex(0xff))
+            padding = n - length
+            for i in range(padding):
+                hex_array.append(args.fill if args.fill is not None else hex(0xFF))
 
-        chunks = [hex_array[i : i + sqrt_n] for i in range(0, len(hex_array), sqrt_n)]
+        width = int(args.w or sqrt_n)
+        chunks = [hex_array[i : i + width] for i in range(0, len(hex_array), width)]
 
         for chunk in chunks:
             for i in chunk:
